@@ -42,8 +42,8 @@ bayesglm.h <- function ( formula, family = gaussian, data, weights, subset,
     }
     if (!drop.baseline){
         X <- if (!is.empty.model(mt)){ 
-            class(mt) <- c("bayesglm.h", "terms", "formula")
-            model.matrix.bayes( mt, mf, contrasts, keep.order=keep.order, batch=batch ) 
+            #class(mt) <- c("bayesglm.h", "terms", "formula")
+            model.matrix.bayes.h( mt, mf, contrasts, keep.order=keep.order, batch=batch ) 
             }
         else matrix(, NROW(Y), 0)
     }
